#
# spec file for package kImageAnnotator
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   0
%define libname libkImageAnnotator%{sover}
Name:           kImageAnnotator
Version:        0.6.1
Release:        1.2
Summary:        Tool for annotating images
License:        GPL-2.0-or-later
Group:          Development/Tools/Other
URL:            https://github.com/ksnip/kImageAnnotator
Source:         https://github.com/ksnip/kImageAnnotator/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  kColorPicker-devel >= 0.2.0
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(x11)
%lang_package

%description
kImageAnnotator is a tool for annotating images.

%package -n %{libname}
Summary:        Tool for annotating images
Group:          System/Libraries

%description -n %{libname}
kImageAnnotator is a tool for annotating images.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
Development files for %{name} including headers and libraries

%prep
%setup -q

%build
%cmake \
    -DBUILD_EXAMPLE=ON \
    -DCMAKE_INSTALL_DATAROOTDIR="share"

%cmake_build

%install
%cmake_install
%find_lang %{name} --with-qt

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%license LICENSE
%doc CHANGELOG.md README.md

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{sover}
%{_libdir}/lib%{name}.so.%{version}

%files devel
%{_libdir}/lib%{name}.so
%{_libdir}/cmake/%{name}
%{_includedir}/%{name}

%files lang -f %{name}.lang
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations

%changelog
* Mon Mar 20 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 0.6.1
  Fixed
  * Fix for unnecessary scrollbars.
  * Add KDE support for scale factor.
  * Show tab tooltips on initial tabs.
  * Sticker resizing is broken when bounding rect flipped.
* Mon May 23 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 0.6.0
  New
  * Add optional undo, redo, crop, scale and modify canvas buttons
    to dock widgets.
  * Cut out vertical or horizontal slice of an image.
  * Middle-click on tab header closes tab.
  * Add button to fit image into current view.
  * Allow changing item opacity.
  * Add support for RGBA colors with transparency.
  * Add mouse cursor sticker.
  * Allow scaling stickers per setting.
  * Respect original aspect ratio of stickers.
  * Respect original size of stickers.
  Fixed
  * Adding image effect does not send image change notification.
  * Blur / Pixelate break when going past image edge once.
  * Item opacity not applied when item shadow disabled.
  Changed
  * Changed kImageAnnotator: Max font size changed to 100pt.
* Thu Nov 25 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.3
  * Fixed: Crash while typing text on wayland.
  * Changed: Show scrollbar when not all tools visible.
* Sun Sep 19 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.2
  Fixed
  * Crashes on destruction. (#242)
  * Memory leaks caught by ASAN. (#243)
  Changed
  * Use system font provided by QGuiApplication as default for
    text tool.
* Sat Jun  5 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.1
  New
  * Add function for loading translations.
  * Add a new tool for creating resizable movable duplicates of
    regions.
  * Add support for hiding annotation settings panel.
  * Add config option for numbering tool to only set next number.
  * Allow manually changing canvas size.
  * Canvas background color configurable.
  * Zoom in and out with keyboard shortcuts.
  * Zoom in and out via buttons from UI.
  * Add reset zoom keyboard shortcut with tooltip.
  * Add keyboard shortcut support for text tool.
  * Allow rotating background image.
  * Allow flipping background image horizontally and vertically.
  * Configurable UI with dockable settings widgets.
  * Add invert color image effect.
  * Allow disabling item shadow per item from UI.
  * Add a font selection to UI.
  * Add zoom in/out capability to crop view.
  * Allow to zoom in modify canvas view.
  * Select item after drawing it and allow changing settings.
  Changed
  * Change drop shadow to cover all sites.
  Fixed
  * Deleting item outside image doesn't decrease canvas size.
  * Duplicate region of grayscale image has color.
  * Marker shows fill and width config when modifying existing
    item.
  * Highlighter/Marker washed out color and overlapping.
  * Popup menus shown outside screen.
  * Not possible to enter value in the width tool.
  * Obfuscation tool shows fonts settings when switching from
    tool with font.
  * Annotation tools are not displayed if application starts with
    docks hidden.
  * Vertical scrollbar missing after using Paste embedded and
    moving the image.
  * Not possible to disable tool automatically deselected after
    drawn.
  * Annotation tool shortcuts do not work if the panel is hidden.
* Wed Mar 24 2021 ecsos <ecsos@opensuse.org>
- Update to 0.4.2
  * Fixed: Fetching image from annotator with HiDPI enabled
    pixelates image. (#218)
  * Fixed: Keep aspect ratio only work when pressing CTRL before
    moving resize handle. (#219)
* Sat Mar 13 2021 ecsos <ecsos@opensuse.org>
- Update to 0.4.1
  * Changed: Horizontally align text inside spin box. (#203)
  * Changed: Change zoom with mouse wheel to CTRL+Wheel. (#210)
  * Fixed: Brazilian Portuguese translation not loaded. (#176)
  * Fixed: error: control reaches end of non-void function. (#177)
  * Fixed: Cursor in Text tool have too bad visibility. (#184)
  * Fixed: bumped SONAME without name change. (#185)
  * Fixed: Entering multiple characters at once moves the text
    cursor only for one character. (#186)
  * Fixed: Activating context menu while drawing item leaves item
    in error state. (#196)
  * Fixed: Icons not scaled on gnome with hdpi enabled. (#201)
  * Fixed: Text/Number Pointer and Text/Number Arrow don't inherit
    Text/Number Font in Settings. (#208)
- Drop 0001-Fix-compiler-warning.patch because no more need.
- Change sover from 0_4_0 to 0 because of rpmlint error.
* Mon Dec  7 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.0
  New:
  * Add Pixelate image area tool.
  * Zoom in and out.
  * Add interface for adding custom tab context menu actions.
  * Add drop shadow to captured images.
  * Add grayscale image effect.
  * Add numeric pointer with arrow annotation item.
  * Add text pointer annotation item.
  * Add text pointer with arrow annotation item.
  * Add option to automatically switching to select tool after
    drawing item.
  * Edit Text box with double click.
  * Resize elements while keeping aspect ratio.
  Changed:
  * Draw point when clicking and releasing without moving cursor.
  * Zoom out less than 100%%.
  * Change to select tool after adding new annotation item.
  * Move current zoom text to left side config panel.
  Fixed:
  * Blur radius not updated when changing current items settings.
  * Text tool opens many unix sockets.
  * Text No Border and No Fill shows shadow beneath text.
  * Item properties remain displayed after item is removed or
    deselected.
  * Changing text box through editing text doesn't update resize
    handles.
- Drop not longer needed patches:
  * 0001-Make-link-against-X11-private.patch
  * 0002-Make-kcolorpicker-link-private.patch
- Add patch:
  * 0001-Fix-compiler-warning.patch
* Sun Sep 13 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patches to mark private link target as such:
  * 0001-Make-link-against-X11-private.patch
  * 0002-Make-kcolorpicker-link-private.patch
* Fri Jul 31 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.3.2
  * Fixed: Tests fail to build with shared library.
* Thu Jun 25 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.3.1
  Fixed:
  * Crashes after undoing a number annotation.
  * Text overlapping when resizing text box.
  * Snap lines to degrees not working when CTRL pressed before
    clicking annotation area.
  * Undo removes several or all items.
  * Marker Rect and Ellipse draw only border but no fill.
* Fri Jun 19 2020 Martin Hauke <mardnh@gmx.de>
- Move files LICENSE, CHANGELOG.md and README.md into
  package kImageAnnotator.
* Fri Jun 19 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.3.0
  New:
  * Add option to translate UI.
  * Saved image expand to include annotations out of border.
  * Add support for stickers.
  * Add tab context menu for close all tabs and close other tabs.
  * Add Number with Arrow/pointer tool.
  Changed:
  * Make dropdown buttons show popup on click.
  * Hide unavailable setting widgets.
  * Make arrow size decrease with stroke size.
  Fixed:
  * Using select tool marks image as changed.
  * Emoticon selector shows a half of current emoticon.
  * FillPicker text or icon sometimes not visible.
  * Wrong image scaling on hdpi screen.
  * Copy area size differs from last capture.
  * Number Tool not reset when switching between tabs.
- Remove patches (fixed upstream):
  * 0001-Improve-kcolorpicker-linking.patch
  * 0001-Don-t-use-lowercase-Qt-keywords-in-public-headers.patch
- Package language files
* Thu Apr 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patches to fix building against libkImageAnnotator:
  * 0001-Don-t-use-lowercase-Qt-keywords-in-public-headers.patch
  * 0001-Improve-kcolorpicker-linking.patch
- Update URLs to new location on GitHub
- Match the full soversion in %%files to prevent mismatches
* Wed Feb 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.2.1
  Fixes:
  * Edit border around text box doesn't disappear when done with
    editing.
  * Edit border not shown under Windows when NoFillNoBorder
    selected for Text Tool.
  * Drawing text tool rect from right to left and bottom top create
    no rect.
  * Text Tool FillType selection not saved.
  * Icons not scaled with HiDPI.
  * Text Cursor not show on Linux.
* Sun Feb  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.2.0
  New:
  * Edit text box content.
  * Panning image by holding space or mouse middle button and
    dragging.
  * Change annotation element config after drawing.
  Changed:
  * Increase blur level so that large text is not visible.
  * Crop widget updates shows via cursor if something is movable.
  * Multi-tool buttons select current (last) tool on single click.
  Fixed:
  * Unable to select number annotation when clicking on the number
    without background.
  * Ctrl Modifier stuck on second or third screenshot with Ctrl-N.
  * Undo/Redo is now disabled during crop and scale operation.
  * Mess with russian letters in text tool when typing in Russian.
  * Text tool does not allow me to type accents.
  * Highlighter rect and ellipse have only border but no fill.
  * Saved tool selection not loaded on startup.
  * On startup does not highlight tool, when this tool not the
    first item in the list.
  * Cursor image cannot be grabbed for moving.
  * Accents still not work in text tool on Linux.
* Sun Dec 29 2019 Martin Hauke <mardnh@gmx.de>
- Package stable release, version 0.1.0
- Add license file
* Thu Jun  6 2019 Андрей Алыпов <and.november@opensuse.org>
- initial package (version 0.0.2) for openSUSE
